In desktop or big screens, the project workspace allows the user to squeeze the code editor unill it's fully collapsed and not visible. When it's in that state and then the user attempts to open a file, visually, it looks like nothing happended even though the file tab was already opened but in the collapsed editor. This can be confusing for users and in such scenario, opening any new tabs in the code editor should automatically expand the code editor and make it visible.